<?php
/**
 * The template for displaying service posts on the front page
 *
 * @package Signify
 */

$show_content  = get_theme_mod( 'signify_service_show', 'excerpt' );
$show_meta     = get_theme_mod( 'signify_service_meta_show', 'hide-meta' );
$signify_type = get_theme_mod( 'signify_service_type', 'category' );
$number        = get_theme_mod( 'signify_service_number', 3 );

$post_list  = array();
$no_of_post = 0;

$args = array(
	'post_type'           => 'post',
	'ignore_sticky_posts' => 1, // ignore sticky posts.
);

// Get valid number of posts.
if ( 'post' === $signify_type || 'page' === $signify_type || 'ect-service' === $signify_type ) {
	$args['post_type'] = $signify_type;

	for ( $i = 1; $i <= $number; $i++ ) {
		$signify_post_id = '';

		if ( 'post' === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_service_post_' . $i );
		} elseif ( 'page' === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_service_page_' . $i );
		} elseif ( 'ect-service' === $signify_type ) {
			$signify_post_id = get_theme_mod( 'signify_service_cpt_' . $i );
		}

		if ( $signify_post_id ) {
			$post_list = array_merge( $post_list, array( $signify_post_id ) );

			$no_of_post++;
		}
	}

	$args['post__in'] = $post_list;
	$args['orderby']  = 'post__in';
} elseif ( 'category' === $signify_type ) {
	if ( $signify_cat = get_theme_mod( 'signify_service_select_category' ) ) {
		$args['category__in'] = $signify_cat;
	}

	$no_of_post = $number;
}

$args['posts_per_page'] = $no_of_post;

if ( ! $no_of_post ) {
	return;
}

$loop = new WP_Query( $args );

while ( $loop->have_posts() ) :

	$loop->the_post();
	$no_thumb = trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-thumb-140x140.jpg';
	?>
	<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
		<div class="hentry-inner">
			<?php if( has_post_thumbnail() ) : ?>
				<div class="post-thumbnail">
					<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<img src="<?php the_post_thumbnail_url( 'thumbnail' ); ?>">
					</a>
				</div>
			<?php else : ?>
				<div class="post-thumbnail">
					<a class="cover-link" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<img src="<?php echo esc_url( $no_thumb ); ?>">
					</a>
				</div>
			<?php endif; ?>

			<div class="entry-container">
				<header class="entry-header">
					<?php if ( 'show-meta' === $show_meta  && ( 'ect-service' == $signify_type || 'post' === $signify_type || 'category' === $signify_type ) ) : ?>
						<div class="entry-meta">
							<div class="entry-category">
								<?php signify_cat_list(); ?>
							</div>
						</div>
					<?php endif; ?>
					<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>

					<?php if ( 'show-meta' === $show_meta  && 'custom' !== $signify_type ) : ?>
					<div class="entry-meta">
						<?php signify_posted_on(); ?>
					</div><!-- .entry-meta -->
					<?php endif; ?>

				</header>

				<?php
				if ( 'excerpt' === $show_content ) {
					?>
					<div class="entry-summary"><?php the_excerpt(); ?></div><!-- .entry-summary -->
					<?php
				} elseif ( 'full-content' === $show_content ) {
					$content = get_the_content();
					echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
				} ?>
			</div><!-- .entry-container -->
		</div> <!-- .hentry-inner -->
	</article> <!-- .article -->
	<?php
endwhile;

wp_reset_postdata();
